import sys
import typing


class AddonPreferences:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Bone:
    basename = None
    ''''''

    bl_rna = None
    ''''''

    center = None
    ''''''

    children = None
    ''''''

    children_recursive = None
    ''''''

    children_recursive_basename = None
    ''''''

    id_data = None
    ''''''

    length = None
    ''''''

    parent_recursive = None
    ''''''

    vector = None
    ''''''

    x_axis = None
    ''''''

    y_axis = None
    ''''''

    z_axis = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def parent_index(self, parent_test):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def translate(self, vec):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class CompositorNode:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def update(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Context:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def copy(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class EditBone:
    basename = None
    ''''''

    bl_rna = None
    ''''''

    center = None
    ''''''

    children = None
    ''''''

    children_recursive = None
    ''''''

    children_recursive_basename = None
    ''''''

    id_data = None
    ''''''

    length = None
    ''''''

    parent_recursive = None
    ''''''

    vector = None
    ''''''

    x_axis = None
    ''''''

    y_axis = None
    ''''''

    z_axis = None
    ''''''

    def align_orientation(self, other):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def parent_index(self, parent_test):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def transform(self, matrix, scale, roll):
        '''

        '''
        pass

    def translate(self, vec):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Group:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_dupli_group = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Header:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class KeyingSetInfo:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Library:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_id = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Macro:
    id_data = None
    ''''''

    order = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def define(self, opname):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Menu:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def draw_collapsible(self, context, layout):
        '''

        '''
        pass

    def draw_preset(self, context):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_menu(self, searchpaths, operator, props_default, prop_filepath,
                  filter_ext, filter_path, display_name):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Mesh:
    bl_rna = None
    ''''''

    cycles = None
    ''''''

    edge_keys = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def from_pydata(self, vertices, edges, faces):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class MeshEdge:
    id_data = None
    ''''''

    key = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class MeshPolygon:
    edge_keys = None
    ''''''

    id_data = None
    ''''''

    loop_indices = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class MeshTessFace:
    center = None
    ''''''

    edge_keys = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Node:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeInternal:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeSocket:
    id_data = None
    ''''''

    links = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeSocketInterface:
    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class NodeTree:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Object:
    bl_rna = None
    ''''''

    children = None
    ''''''

    cycles = None
    ''''''

    cycles_visibility = None
    ''''''

    id_data = None
    ''''''

    users_group = None
    ''''''

    users_scene = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Operator:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    order = None
    ''''''

    def as_keywords(self, ignore):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class OrderedDictMini:
    def clear(self):
        '''

        '''
        pass

    def copy(self):
        '''

        '''
        pass

    def fromkeys(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def pop(self):
        '''

        '''
        pass

    def popitem(self):
        '''

        '''
        pass

    def setdefault(self):
        '''

        '''
        pass

    def update(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class OrderedMeta:
    is_registered = None
    ''''''

    def mro(self):
        '''

        '''
        pass


class Panel:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class PoseBone:
    basename = None
    ''''''

    bl_rna = None
    ''''''

    center = None
    ''''''

    children = None
    ''''''

    children_recursive = None
    ''''''

    children_recursive_basename = None
    ''''''

    id_data = None
    ''''''

    length = None
    ''''''

    parent_recursive = None
    ''''''

    vector = None
    ''''''

    x_axis = None
    ''''''

    y_axis = None
    ''''''

    z_axis = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def parent_index(self, parent_test):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def translate(self, vec):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class PropertyGroup:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class RNAMeta:
    is_registered = None
    ''''''

    def mro(self):
        '''

        '''
        pass


class RNAMetaPropGroup:
    is_registered = None
    ''''''

    def mro(self):
        '''

        '''
        pass


class RenderEngine:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class ShaderNode:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Sound:
    bl_rna = None
    ''''''

    factory = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Text:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_logic = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def as_string(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def from_string(self, string):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class Texture:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    users_material = None
    ''''''

    users_object_modifier = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class TextureNode:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def is_registered_node_type(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def poll(self, ntree):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class UIList:
    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def append(self, draw_func):
        '''

        '''
        pass

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def is_extended(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def prepend(self, draw_func):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def remove(self, draw_func):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


class WindowManager:
    addon_filter = None
    ''''''

    addon_search = None
    ''''''

    addon_support = None
    ''''''

    bl_rna = None
    ''''''

    id_data = None
    ''''''

    def as_pointer(self):
        '''

        '''
        pass

    def driver_add(self):
        '''

        '''
        pass

    def driver_remove(self):
        '''

        '''
        pass

    def fileselect_add(self):
        '''

        '''
        pass

    def get(self):
        '''

        '''
        pass

    def invoke_confirm(self):
        '''

        '''
        pass

    def invoke_popup(self):
        '''

        '''
        pass

    def invoke_props_dialog(self):
        '''

        '''
        pass

    def invoke_props_popup(self):
        '''

        '''
        pass

    def invoke_search_popup(self):
        '''

        '''
        pass

    def is_property_hidden(self):
        '''

        '''
        pass

    def is_property_readonly(self):
        '''

        '''
        pass

    def is_property_set(self):
        '''

        '''
        pass

    def items(self):
        '''

        '''
        pass

    def keyframe_delete(self):
        '''

        '''
        pass

    def keyframe_insert(self):
        '''

        '''
        pass

    def keys(self):
        '''

        '''
        pass

    def modal_handler_add(self):
        '''

        '''
        pass

    def path_from_id(self):
        '''

        '''
        pass

    def path_resolve(self):
        '''

        '''
        pass

    def piemenu_begin__internal(self):
        '''

        '''
        pass

    def piemenu_end__internal(self):
        '''

        '''
        pass

    def popup_menu(self, draw_func, title, icon):
        '''

        '''
        pass

    def popup_menu_pie(self, event, draw_func, title, icon):
        '''

        '''
        pass

    def property_unset(self):
        '''

        '''
        pass

    def pupmenu_begin__internal(self):
        '''

        '''
        pass

    def pupmenu_end__internal(self):
        '''

        '''
        pass

    def type_recast(self):
        '''

        '''
        pass

    def values(self):
        '''

        '''
        pass


def ord_ind(i1, i2):
    '''

    '''

    pass



import sys
import typing
keymaps_description_doc = None
'''constant value ‘nkeymaps_description is a tuple (((keymap_description), (tuple of keymap_item_descriptions))).nkeymap_description is a tuple (name, space_type, region_type, is_modal).nkeymap_item_description is a tuple ({kw_args_for_keymap_new}, (tuple of properties)).nkw_args_for_keymap_new is a mapping which keywords match parameters of keymap.new() function.ntuple of properties is a tuple of pairs (prop_name, prop_value) (properties being those of called operator).nnExample:nnKEYMAPS = (n # First, keymap identifiers (last bool is True for modal km).n ((‘Sequencer, ‘SEQUENCE_EDITOR, ‘WINDOW, False), (n # Then a tuple of keymap items, defined by a dict of kwargs for the km new func, and a tuple of tuples (name, val)n # for ops properties, if needing non-default values.n ({“idname”: export_strips.SEQExportStrip.bl_idname, “type”: ‘P, “value”: ‘PRESS, “shift”: True, “ctrl”: True},n ()),n )),n)n '''


def addon_keymap_register(wm, keymaps_description):
    '''

    '''

    pass


def addon_keymap_unregister(wm, keymaps_description):
    '''

    '''

    pass


def keyconfig_export(wm, kc, filepath):
    '''

    '''

    pass


def keyconfig_merge(kc1, kc2):
    '''note: kc1 takes priority over kc2 

    '''

    pass


def keyconfig_test(kc):
    '''

    '''

    pass


def km_exists_in(km, export_keymaps):
    '''

    '''

    pass



import sys
import typing
import bpy

from . import offscreen

CD_MCOL = None
'''There can be more than one attribute of that type, they are differenciated by name. In blender you can retrieve the attribute data with: '''

CD_MTFACE = None
'''There can be more than one attribute of that type, they are differenciated by name. In blender, you can retrieve the attribute data with: '''

CD_ORCO = None
'''There can be only 1 attribute of that type per shader. In blender you can retrieve the attribute data with: '''

CD_TANGENT = None
'''There can be only 1 attribute of that type per shader. There is currently no way to retrieve this attribute data via the RNA API but a standalone C function to compute the tangent layer from the other layers can be obtained from blender.org. '''

GPU_DATA_16F = None
'''matrix 4x4 in column-major order '''

GPU_DATA_1F = None
'''one float '''

GPU_DATA_1I = None
'''one integer '''

GPU_DATA_2F = None
'''two floats '''

GPU_DATA_3F = None
'''three floats '''

GPU_DATA_4F = None
'''four floats '''

GPU_DATA_4UB = None
'''four unsigned byte '''

GPU_DATA_9F = None
'''matrix 3x3 in column-major order '''

GPU_DYNAMIC_AMBIENT_COLOR = None
'''See bpy.types.World.ambient_color. '''

GPU_DYNAMIC_HORIZON_COLOR = None
'''See bpy.types.World.horizon_color. '''

GPU_DYNAMIC_LAMP_ATT1: float = None
'''See bpy.types.PointLamp.linear_attenuation, bpy.types.SpotLamp.linear_attenuation. '''

GPU_DYNAMIC_LAMP_ATT2: float = None
'''See bpy.types.PointLamp.quadratic_attenuation, bpy.types.SpotLamp.quadratic_attenuation. '''

GPU_DYNAMIC_LAMP_DISTANCE: float = None
'''See bpy.types.Lamp.distance. '''

GPU_DYNAMIC_LAMP_DYNCO = None
'''Represents the position of the light in camera space. '''

GPU_DYNAMIC_LAMP_DYNCOL = None
'''See bpy.types.Lamp.color. '''

GPU_DYNAMIC_LAMP_DYNENERGY: float = None
'''See bpy.types.Lamp.energy. '''

GPU_DYNAMIC_LAMP_DYNIMAT = None
'''Matrix that converts vector in camera space to lamp space. '''

GPU_DYNAMIC_LAMP_DYNPERSMAT = None
'''mat4_perspective_to_depth is a fixed matrix defined as follow: '''

GPU_DYNAMIC_LAMP_DYNVEC = None
'''Represents the direction of light in camera space. '''

GPU_DYNAMIC_LAMP_SPOTBLEND: float = None
'''See bpy.types.SpotLamp.spot_blend. '''

GPU_DYNAMIC_LAMP_SPOTSCALE = None
'''Represents the SpotLamp local scale. '''

GPU_DYNAMIC_LAMP_SPOTSIZE: float = None
'''See bpy.types.SpotLamp.spot_size. '''

GPU_DYNAMIC_MAT_ALPHA: float = None
'''See bpy.types.Material.alpha. '''

GPU_DYNAMIC_MAT_AMB: float = None
'''See bpy.types.Material.ambient. '''

GPU_DYNAMIC_MAT_DIFFRGB = None
'''See bpy.types.Material.diffuse_color. '''

GPU_DYNAMIC_MAT_EMIT: float = None
'''See bpy.types.Material.emit. '''

GPU_DYNAMIC_MAT_HARD: float = None
'''See bpy.types.Material.specular_hardness. '''

GPU_DYNAMIC_MAT_REF: float = None
'''See bpy.types.Material.diffuse_intensity. '''

GPU_DYNAMIC_MAT_SPEC: float = None
'''See bpy.types.Material.specular_intensity. '''

GPU_DYNAMIC_MAT_SPECRGB = None
'''See bpy.types.Material.specular_color. '''

GPU_DYNAMIC_MIST_COLOR = None

GPU_DYNAMIC_MIST_DISTANCE: float = None
'''See bpy.types.WorldMistSettings.intensity. '''

GPU_DYNAMIC_MIST_ENABLE: float = None
'''See bpy.types.WorldMistSettings.use_mist. '''

GPU_DYNAMIC_MIST_INTENSITY: float = None

GPU_DYNAMIC_MIST_START: float = None
'''See bpy.types.WorldMistSettings.depth. '''

GPU_DYNAMIC_MIST_TYPE: float = None
'''See bpy.types.WorldMistSettings.falloff. '''

GPU_DYNAMIC_OBJECT_AUTOBUMPSCALE: float = None
'''Multiplier for bump-map scaling. '''

GPU_DYNAMIC_OBJECT_COLOR = None
'''See bpy.types.Object.color. '''

GPU_DYNAMIC_OBJECT_IMAT = None
'''The uniform is a 4x4 GL matrix that converts world coodinates to object coordinates (see mat4_world_to_object). '''

GPU_DYNAMIC_OBJECT_MAT = None
'''A matrix that converts object coordinates to world coordinates (see mat4_object_to_world). '''

GPU_DYNAMIC_OBJECT_VIEWIMAT = None
'''The uniform is a 4x4 GL matrix that converts coordinates in camera space to world coordinates (see mat4_cam_to_world). '''

GPU_DYNAMIC_OBJECT_VIEWMAT = None
'''A matrix that converts world coordinates to camera coordinates (see mat4_world_to_cam). '''

GPU_DYNAMIC_SAMPLER_2DBUFFER = None
'''Represents an internal texture used for certain effect (color band, etc). '''

GPU_DYNAMIC_SAMPLER_2DIMAGE = None
'''Represents a texture loaded from an image file. '''

GPU_DYNAMIC_SAMPLER_2DSHADOW = None
'''Represents a texture loaded from a shadow buffer file. '''


def export_shader(scene: 'bpy.types.Scene', material: 'bpy.types.Material'):
    '''Example: 

    :param scene: the scene in which the material in rendered. 
    :type scene: 'bpy.types.Scene'
    :param material: the material that you want to export the GLSL shader 
    :type material: 'bpy.types.Material'
    :return:  the shader source code and all associated data in a dictionary 
    '''

    pass



import sys
import typing


def delete():
    '''Delete active scene 

    '''

    pass


def freestyle_add_edge_marks_to_keying_set():
    '''Add the data paths to the Freestyle Edge Mark property of selected edges to the active keying set 

    '''

    pass


def freestyle_add_face_marks_to_keying_set():
    '''Add the data paths to the Freestyle Face Mark property of selected polygons to the active keying set 

    '''

    pass


def freestyle_alpha_modifier_add(
        type: typing.Union[str, int] = 'ALONG_STROKE'):
    '''Add an alpha transparency modifier to the line style associated with the active lineset 

    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def freestyle_color_modifier_add(
        type: typing.Union[str, int] = 'ALONG_STROKE'):
    '''Add a line color modifier to the line style associated with the active lineset 

    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def freestyle_fill_range_by_selection(type: typing.Union[str, int] = 'COLOR',
                                      name: str = ""):
    '''Fill the Range Min/Max entries by the min/max distance between selected mesh objects and the source object 

    :param type: Type, Type of the modifier to work onCOLOR Color, Color modifier type.ALPHA Alpha, Alpha modifier type.THICKNESS Thickness, Thickness modifier type. 
    :type type: typing.Union[str, int]
    :param name: Name, Name of the modifier to work on 
    :type name: str
    '''

    pass


def freestyle_geometry_modifier_add(
        type: typing.Union[str, int] = '2D_OFFSET'):
    '''Add a stroke geometry modifier to the line style associated with the active lineset 

    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def freestyle_lineset_add():
    '''Add a line set into the list of line sets 

    '''

    pass


def freestyle_lineset_copy():
    '''Copy the active line set to a buffer 

    '''

    pass


def freestyle_lineset_move(direction: typing.Union[str, int] = 'UP'):
    '''Change the position of the active line set within the list of line sets 

    :param direction: Direction, Direction to move the active line set towards 
    :type direction: typing.Union[str, int]
    '''

    pass


def freestyle_lineset_paste():
    '''Paste the buffer content to the active line set 

    '''

    pass


def freestyle_lineset_remove():
    '''Remove the active line set from the list of line sets 

    '''

    pass


def freestyle_linestyle_new():
    '''Create a new line style, reusable by multiple line sets 

    '''

    pass


def freestyle_modifier_copy():
    '''Duplicate the modifier within the list of modifiers 

    '''

    pass


def freestyle_modifier_move(direction: typing.Union[str, int] = 'UP'):
    '''Move the modifier within the list of modifiers 

    :param direction: Direction, Direction to move the chosen modifier towards 
    :type direction: typing.Union[str, int]
    '''

    pass


def freestyle_modifier_remove():
    '''Remove the modifier from the list of modifiers 

    '''

    pass


def freestyle_module_add():
    '''Add a style module into the list of modules 

    '''

    pass


def freestyle_module_move(direction: typing.Union[str, int] = 'UP'):
    '''Change the position of the style module within in the list of style modules 

    :param direction: Direction, Direction to move the chosen style module towards 
    :type direction: typing.Union[str, int]
    '''

    pass


def freestyle_module_open(filepath: str = "", make_internal: bool = True):
    '''Open a style module file 

    :param filepath: filepath 
    :type filepath: str
    :param make_internal: Make internal, Make module file internal after loading 
    :type make_internal: bool
    '''

    pass


def freestyle_module_remove():
    '''Remove the style module from the stack 

    '''

    pass


def freestyle_stroke_material_create():
    '''Create Freestyle stroke material for testing 

    '''

    pass


def freestyle_thickness_modifier_add(
        type: typing.Union[str, int] = 'ALONG_STROKE'):
    '''Add a line thickness modifier to the line style associated with the active lineset 

    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def new(type: typing.Union[str, int] = 'NEW'):
    '''Add new scene by type 

    :param type: TypeNEW New, Add new scene.EMPTY Copy Settings, Make a copy without any objects.LINK_OBJECTS Link Objects, Link to the objects from the current scene.LINK_OBJECT_DATA Link Object Data, Copy objects linked to data from the current scene.FULL_COPY Full Copy, Make a full copy of the current scene. 
    :type type: typing.Union[str, int]
    '''

    pass


def render_layer_add():
    '''Add a render layer 

    '''

    pass


def render_layer_remove():
    '''Remove the selected render layer 

    '''

    pass


def render_view_add():
    '''Add a render view 

    '''

    pass


def render_view_remove():
    '''Remove the selected render view 

    '''

    pass


def units_length_preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove length units preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass



import sys
import typing
frame_change_post = None
'''on frame change for playback and rendering (after) '''

frame_change_pre = None
'''on frame change for playback and rendering (before) '''

game_post = None
'''on ending the game engine '''

game_pre = None
'''on starting the game engine '''

load_post = None
'''on loading a new blend file (after) '''

load_pre = None
'''on loading a new blend file (before) '''

persistent = None
'''Function decorator for callback functions not to be removed when loading new files '''

render_cancel = None
'''on canceling a render job '''

render_complete = None
'''on completion of render job '''

render_init = None
'''on initialization of a render job '''

render_post = None
'''on render (after) '''

render_pre = None
'''on render (before) '''

render_stats = None
'''on printing render statistics '''

render_write = None
'''on writing a render frame (directly after the frame is written) '''

save_post = None
'''on saving a blend file (after) '''

save_pre = None
'''on saving a blend file (before) '''

scene_update_post = None
'''on every scene data update. Does not imply that anything changed in the scene, just that the dependency graph was reevaluated, and the scene was possibly updated by Blenders animation system. '''

scene_update_pre = None
'''on every scene data update. Does not imply that anything changed in the scene, just that the dependency graph is about to be reevaluated, and the scene is about to be updated by Blenders animation system. '''

version_update = None
'''on ending the versioning code '''



import sys
import typing


def open(filepath: str = "",
         check_existing: bool = True,
         filter_blender: bool = False,
         filter_backup: bool = False,
         filter_image: bool = False,
         filter_movie: bool = False,
         filter_python: bool = False,
         filter_font: bool = False,
         filter_sound: bool = False,
         filter_text: bool = False,
         filter_btx: bool = False,
         filter_collada: bool = False,
         filter_alembic: bool = True,
         filter_folder: bool = True,
         filter_blenlib: bool = False,
         filemode: int = 8,
         display_type: typing.Union[str, int] = 'DEFAULT',
         sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA'):
    '''Load a cache file 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    '''

    pass


def reload():
    '''Update objects paths list with new data from the archive 

    '''

    pass



import sys
import typing
import bpy


def bake_action(frame_start: int,
                frame_end: int,
                frame_step: int = 1,
                only_selected: bool = False,
                do_pose: bool = True,
                do_object: bool = True,
                do_visual_keying: bool = True,
                do_constraint_clear: bool = False,
                do_parents_clear: bool = False,
                do_clean: bool = False,
                action: 'bpy.types.Action' = None) -> 'bpy.types.Action':
    '''Return an image from the file path with options to search multiple paths and return a placeholder if its not found. 

    :param frame_start: First frame to bake. 
    :type frame_start: int
    :param frame_end: Last frame to bake. 
    :type frame_end: int
    :param frame_step: Frame step. 
    :type frame_step: int
    :param only_selected: Only bake selected bones. 
    :type only_selected: bool
    :param do_pose: Bake pose channels. 
    :type do_pose: bool
    :param do_object: Bake objects. 
    :type do_object: bool
    :param do_visual_keying: Use the final transformations for baking (‘visual keying’) 
    :type do_visual_keying: bool
    :param do_constraint_clear: Remove constraints after baking. 
    :type do_constraint_clear: bool
    :param do_parents_clear: Unparent after baking objects. 
    :type do_parents_clear: bool
    :param do_clean: Remove redundant keyframes after baking. 
    :type do_clean: bool
    :param action: An action to bake the data into, or None for a new action to be created. 
    :type action: 'bpy.types.Action'
    :return:  an action or None 
    '''

    pass



import sys
import typing
import bpy


def cyclic_toggle(direction: typing.Union[str, int] = 'CYCLIC_U'):
    '''Make active spline closed/opened loop 

    :param direction: Direction, Direction to make surface cyclic in 
    :type direction: typing.Union[str, int]
    '''

    pass


def de_select_first():
    '''(De)select first of visible part of each NURBS 

    '''

    pass


def de_select_last():
    '''(De)select last of visible part of each NURBS 

    '''

    pass


def delete(type: typing.Union[str, int] = 'VERT'):
    '''Delete selected control points or segments 

    :param type: Type, Which elements to delete 
    :type type: typing.Union[str, int]
    '''

    pass


def dissolve_verts():
    '''Delete selected control points, correcting surrounding handles 

    '''

    pass


def draw(error_threshold: float = 0.0,
         fit_method: typing.Union[str, int] = 'REFIT',
         corner_angle: float = 1.22173,
         use_cyclic: bool = True,
         stroke: typing.List['bpy.types.OperatorStrokeElement'] = None,
         wait_for_input: bool = True):
    '''Draw a freehand spline 

    :param error_threshold: Error, Error distance threshold (in object units) 
    :type error_threshold: float
    :param fit_method: Fit MethodREFIT Refit, Incrementally re-fit the curve (high quality).SPLIT Split, Split the curve until the tolerance is met (fast). 
    :type fit_method: typing.Union[str, int]
    :param corner_angle: Corner Angle 
    :type corner_angle: float
    :param use_cyclic: Cyclic 
    :type use_cyclic: bool
    :param stroke: Stroke 
    :type stroke: typing.List['bpy.types.OperatorStrokeElement']
    :param wait_for_input: Wait for Input 
    :type wait_for_input: bool
    '''

    pass


def duplicate():
    '''Duplicate selected control points 

    '''

    pass


def duplicate_move(CURVE_OT_duplicate=None, TRANSFORM_OT_translate=None):
    '''Duplicate curve and move 

    :param CURVE_OT_duplicate: Duplicate Curve, Duplicate selected control points 
    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items 
    '''

    pass


def extrude(mode: typing.Union[str, int] = 'TRANSLATION'):
    '''Extrude selected control point(s) 

    :param mode: Mode 
    :type mode: typing.Union[str, int]
    '''

    pass


def extrude_move(CURVE_OT_extrude=None, TRANSFORM_OT_translate=None):
    '''Extrude curve and move result 

    :param CURVE_OT_extrude: Extrude, Extrude selected control point(s) 
    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items 
    '''

    pass


def handle_type_set(type: typing.Union[str, int] = 'AUTOMATIC'):
    '''Set type of handles for selected control points 

    :param type: Type, Spline type 
    :type type: typing.Union[str, int]
    '''

    pass


def hide(unselected: bool = False):
    '''Hide (un)selected control points 

    :param unselected: Unselected, Hide unselected rather than selected 
    :type unselected: bool
    '''

    pass


def make_segment():
    '''Join two curves by their selected ends 

    '''

    pass


def match_texture_space():
    '''Match texture space to object’s bounding box 

    '''

    pass


def normals_make_consistent(calc_length: bool = False):
    '''Recalculate the direction of selected handles 

    :param calc_length: Length, Recalculate handle length 
    :type calc_length: bool
    '''

    pass


def primitive_bezier_circle_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Bezier Circle 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_bezier_curve_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Bezier Curve 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_circle_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs Circle 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_curve_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Nurbs Curve 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def primitive_nurbs_path_add(
        radius: float = 1.0,
        view_align: bool = False,
        enter_editmode: bool = False,
        location: float = (0.0, 0.0, 0.0),
        rotation: float = (0.0, 0.0, 0.0),
        layers: bool = (False, False, False, False, False, False, False, False,
                        False, False, False, False, False, False, False, False,
                        False, False, False, False)):
    '''Construct a Path 

    :param radius: Radius 
    :type radius: float
    :param view_align: Align to View, Align the new object to the view 
    :type view_align: bool
    :param enter_editmode: Enter Editmode, Enter editmode when adding this object 
    :type enter_editmode: bool
    :param location: Location, Location for the newly added object 
    :type location: float
    :param rotation: Rotation, Rotation for the newly added object 
    :type rotation: float
    :param layers: Layer 
    :type layers: bool
    '''

    pass


def radius_set(radius: float = 1.0):
    '''Set per-point radius which is used for bevel tapering 

    :param radius: Radius 
    :type radius: float
    '''

    pass


def reveal():
    '''Show again hidden control points 

    '''

    pass


def select_all(action: typing.Union[str, int] = 'TOGGLE'):
    '''(De)select all control points 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[str, int]
    '''

    pass


def select_less():
    '''Reduce current selection by deselecting boundary elements 

    '''

    pass


def select_linked():
    '''Select all control points linked to active one 

    '''

    pass


def select_linked_pick(deselect: bool = False):
    '''Select all control points linked to already selected ones 

    :param deselect: Deselect, Deselect linked control points rather than selecting them 
    :type deselect: bool
    '''

    pass


def select_more():
    '''Select control points directly linked to already selected ones 

    '''

    pass


def select_next():
    '''Select control points following already selected ones along the curves 

    '''

    pass


def select_nth(nth: int = 2, skip: int = 1, offset: int = 0):
    '''Deselect every other vertex 

    :param nth: Nth Selection 
    :type nth: int
    :param skip: Skip 
    :type skip: int
    :param offset: Offset 
    :type offset: int
    '''

    pass


def select_previous():
    '''Select control points preceding already selected ones along the curves 

    '''

    pass


def select_random(percent: float = 50.0,
                  seed: int = 0,
                  action: typing.Union[str, int] = 'SELECT'):
    '''Randomly select some control points 

    :param percent: Percent, Percentage of objects to select randomly 
    :type percent: float
    :param seed: Random Seed, Seed for the random number generator 
    :type seed: int
    :param action: Action, Selection action to executeSELECT Select, Select all elements.DESELECT Deselect, Deselect all elements. 
    :type action: typing.Union[str, int]
    '''

    pass


def select_row():
    '''Select a row of control points including active one 

    '''

    pass


def select_similar(type: typing.Union[str, int] = 'WEIGHT',
                   compare: typing.Union[str, int] = 'EQUAL',
                   threshold: float = 0.1):
    '''Select similar curve points by property type 

    :param type: Type 
    :type type: typing.Union[str, int]
    :param compare: Compare 
    :type compare: typing.Union[str, int]
    :param threshold: Threshold 
    :type threshold: float
    '''

    pass


def separate():
    '''Separate selected points from connected unselected points into a new object 

    '''

    pass


def shade_flat():
    '''Set shading to flat 

    '''

    pass


def shade_smooth():
    '''Set shading to smooth 

    '''

    pass


def shortest_path_pick():
    '''Select shortest path between two selections 

    '''

    pass


def smooth():
    '''Flatten angles of selected points 

    '''

    pass


def smooth_radius():
    '''Interpolate radii of selected points 

    '''

    pass


def smooth_tilt():
    '''Interpolate tilt of selected points 

    '''

    pass


def smooth_weight():
    '''Interpolate weight of selected points 

    '''

    pass


def spin(center: float = (0.0, 0.0, 0.0), axis: float = (0.0, 0.0, 0.0)):
    '''Extrude selected boundary row around pivot point and current view axis 

    :param center: Center, Center in global view space 
    :type center: float
    :param axis: Axis, Axis in global view space 
    :type axis: float
    '''

    pass


def spline_type_set(type: typing.Union[str, int] = 'POLY',
                    use_handles: bool = False):
    '''Set type of active spline 

    :param type: Type, Spline type 
    :type type: typing.Union[str, int]
    :param use_handles: Handles, Use handles when converting bezier curves into polygons 
    :type use_handles: bool
    '''

    pass


def spline_weight_set(weight: float = 1.0):
    '''Set softbody goal weight for selected points 

    :param weight: Weight 
    :type weight: float
    '''

    pass


def split():
    '''Split off selected points from connected unselected points 

    '''

    pass


def subdivide(number_cuts: int = 1):
    '''Subdivide selected segments 

    :param number_cuts: Number of cuts 
    :type number_cuts: int
    '''

    pass


def switch_direction():
    '''Switch direction of selected splines 

    '''

    pass


def tilt_clear():
    '''Clear the tilt of selected control points 

    '''

    pass


def vertex_add(location: float = (0.0, 0.0, 0.0)):
    '''Add a new control point (linked to only selected end-curve one, if any) 

    :param location: Location, Location to add new vertex at 
    :type location: float
    '''

    pass



import sys
import typing


def compat_str(text, line_length):
    '''

    '''

    pass


def graph_armature(obj, filepath, FAKE_PARENT, CONSTRAINTS, DRIVERS,
                   XTRA_INFO):
    '''

    '''

    pass



import sys
import typing
import bpy


def add_and_link_node(use_transform: bool = False,
                      settings: typing.List['bpy.types.NodeSetting'] = None,
                      type: str = "",
                      link_socket_index: int = 0):
    '''Add a node to the active tree and link to an existing socket 

    :param use_transform: Use Transform, Start transform operator after inserting the node 
    :type use_transform: bool
    :param settings: Settings, Settings to be applied on the newly created node 
    :type settings: typing.List['bpy.types.NodeSetting']
    :param type: Node Type, Node type 
    :type type: str
    :param link_socket_index: Link Socket Index, Index of the socket to link 
    :type link_socket_index: int
    '''

    pass


def add_file(filepath: str = "",
             filter_blender: bool = False,
             filter_backup: bool = False,
             filter_image: bool = True,
             filter_movie: bool = True,
             filter_python: bool = False,
             filter_font: bool = False,
             filter_sound: bool = False,
             filter_text: bool = False,
             filter_btx: bool = False,
             filter_collada: bool = False,
             filter_alembic: bool = False,
             filter_folder: bool = True,
             filter_blenlib: bool = False,
             filemode: int = 9,
             relative_path: bool = True,
             show_multiview: bool = False,
             use_multiview: bool = False,
             display_type: typing.Union[str, int] = 'DEFAULT',
             sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
             name: str = "Image"):
    '''Add a file node to the current node editor 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param relative_path: Relative Path, Select the file relative to the blend file 
    :type relative_path: bool
    :param show_multiview: Enable Multi-View 
    :type show_multiview: bool
    :param use_multiview: Use Multi-View 
    :type use_multiview: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param name: Name, Data-block name to assign 
    :type name: str
    '''

    pass


def add_mask(name: str = "Mask"):
    '''Add a mask node to the current node editor 

    :param name: Name, Data-block name to assign 
    :type name: str
    '''

    pass


def add_node(use_transform: bool = False,
             settings: typing.List['bpy.types.NodeSetting'] = None,
             type: str = ""):
    '''Add a node to the active tree 

    :param use_transform: Use Transform, Start transform operator after inserting the node 
    :type use_transform: bool
    :param settings: Settings, Settings to be applied on the newly created node 
    :type settings: typing.List['bpy.types.NodeSetting']
    :param type: Node Type, Node type 
    :type type: str
    '''

    pass


def add_reroute(path: typing.List['bpy.types.OperatorMousePath'] = None,
                cursor: int = 6):
    '''Add a reroute node 

    :param path: path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    :param cursor: Cursor 
    :type cursor: int
    '''

    pass


def add_search(use_transform: bool = False,
               settings: typing.List['bpy.types.NodeSetting'] = None,
               type: str = "",
               node_item: typing.Union[str, int] = ''):
    '''Add a node to the active tree 

    :param use_transform: Use Transform, Start transform operator after inserting the node 
    :type use_transform: bool
    :param settings: Settings, Settings to be applied on the newly created node 
    :type settings: typing.List['bpy.types.NodeSetting']
    :param type: Node Type, Node type 
    :type type: str
    :param node_item: Node Type, Node type 
    :type node_item: typing.Union[str, int]
    '''

    pass


def attach():
    '''Attach active node to a frame 

    '''

    pass


def backimage_fit():
    '''Fit the background image to the view 

    '''

    pass


def backimage_move():
    '''Move Node backdrop 

    '''

    pass


def backimage_sample():
    '''Use mouse to sample background image 

    '''

    pass


def backimage_zoom(factor: float = 1.2):
    '''Zoom in/out the background image 

    :param factor: Factor 
    :type factor: float
    '''

    pass


def clear_viewer_border():
    '''Clear the boundaries for viewer operations 

    '''

    pass


def clipboard_copy():
    '''Copies selected nodes to the clipboard 

    '''

    pass


def clipboard_paste():
    '''Pastes nodes from the clipboard to the active node tree 

    '''

    pass


def collapse_hide_unused_toggle():
    '''Toggle collapsed nodes and hide unused sockets 

    '''

    pass


def delete():
    '''Delete selected nodes 

    '''

    pass


def delete_reconnect():
    '''Delete nodes; will reconnect nodes as if deletion was muted 

    '''

    pass


def detach():
    '''Detach selected nodes from parents 

    '''

    pass


def detach_translate_attach(NODE_OT_detach=None,
                            TRANSFORM_OT_translate=None,
                            NODE_OT_attach=None):
    '''Detach nodes, move and attach to frame 

    :param NODE_OT_detach: Detach Nodes, Detach selected nodes from parents 
    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items 
    :param NODE_OT_attach: Attach Nodes, Attach active node to a frame 
    '''

    pass


def duplicate(keep_inputs: bool = False):
    '''Duplicate selected nodes 

    :param keep_inputs: Keep Inputs, Keep the input links to duplicated nodes 
    :type keep_inputs: bool
    '''

    pass


def duplicate_move(NODE_OT_duplicate=None, NODE_OT_translate_attach=None):
    '''Duplicate selected nodes and move them 

    :param NODE_OT_duplicate: Duplicate Nodes, Duplicate selected nodes 
    :param NODE_OT_translate_attach: Move and Attach, Move nodes and attach to frame 
    '''

    pass


def duplicate_move_keep_inputs(NODE_OT_duplicate=None,
                               NODE_OT_translate_attach=None):
    '''Duplicate selected nodes keeping input links and move them 

    :param NODE_OT_duplicate: Duplicate Nodes, Duplicate selected nodes 
    :param NODE_OT_translate_attach: Move and Attach, Move nodes and attach to frame 
    '''

    pass


def find_node(prev: bool = False):
    '''Search for named node and allow to select and activate it 

    :param prev: Previous 
    :type prev: bool
    '''

    pass


def group_edit(exit: bool = False):
    '''Edit node group 

    :param exit: Exit 
    :type exit: bool
    '''

    pass


def group_insert():
    '''Insert selected nodes into a node group 

    '''

    pass


def group_make():
    '''Make group from selected nodes 

    '''

    pass


def group_separate(type: typing.Union[str, int] = 'COPY'):
    '''Separate selected nodes from the node group 

    :param type: TypeCOPY Copy, Copy to parent node tree, keep group intact.MOVE Move, Move to parent node tree, remove from group. 
    :type type: typing.Union[str, int]
    '''

    pass


def group_ungroup():
    '''Ungroup selected nodes 

    '''

    pass


def hide_socket_toggle():
    '''Toggle unused node socket display 

    '''

    pass


def hide_toggle():
    '''Toggle hiding of selected nodes 

    '''

    pass


def insert_offset():
    '''Automatically offset nodes on insertion 

    '''

    pass


def join():
    '''Attach selected nodes to a new common frame 

    '''

    pass


def link(detach: bool = False):
    '''Use the mouse to create a link between two nodes 

    :param detach: Detach, Detach and redirect existing links 
    :type detach: bool
    '''

    pass


def link_make(replace: bool = False):
    '''Makes a link between selected output in input sockets 

    :param replace: Replace, Replace socket connections with the new links 
    :type replace: bool
    '''

    pass


def link_viewer():
    '''Link to viewer node 

    '''

    pass


def links_cut(path: typing.List['bpy.types.OperatorMousePath'] = None,
              cursor: int = 9):
    '''Use the mouse to cut (remove) some links 

    :param path: path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    :param cursor: Cursor 
    :type cursor: int
    '''

    pass


def links_detach():
    '''Remove all links to selected nodes, and try to connect neighbor nodes together 

    '''

    pass


def move_detach_links(NODE_OT_links_detach=None,
                      TRANSFORM_OT_translate=None,
                      NODE_OT_insert_offset=None):
    '''Move a node to detach links 

    :param NODE_OT_links_detach: Detach Links, Remove all links to selected nodes, and try to connect neighbor nodes together 
    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items 
    :param NODE_OT_insert_offset: Insert Offset, Automatically offset nodes on insertion 
    '''

    pass


def move_detach_links_release(NODE_OT_links_detach=None,
                              NODE_OT_translate_attach=None):
    '''Move a node to detach links 

    :param NODE_OT_links_detach: Detach Links, Remove all links to selected nodes, and try to connect neighbor nodes together 
    :param NODE_OT_translate_attach: Move and Attach, Move nodes and attach to frame 
    '''

    pass


def mute_toggle():
    '''Toggle muting of the nodes 

    '''

    pass


def new_node_tree(type: typing.Union[str, int] = '', name: str = "NodeTree"):
    '''Create a new node tree 

    :param type: Tree Type 
    :type type: typing.Union[str, int]
    :param name: Name 
    :type name: str
    '''

    pass


def node_color_preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove a Node Color Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass


def node_copy_color():
    '''Copy color to all selected nodes 

    '''

    pass


def options_toggle():
    '''Toggle option buttons display for selected nodes 

    '''

    pass


def output_file_add_socket(file_path: str = "Image"):
    '''Add a new input to a file output node 

    :param file_path: File Path, Sub-path of the output file 
    :type file_path: str
    '''

    pass


def output_file_move_active_socket(direction: typing.Union[str, int] = 'DOWN'):
    '''Move the active input of a file output node up or down the list 

    :param direction: Direction 
    :type direction: typing.Union[str, int]
    '''

    pass


def output_file_remove_active_socket():
    '''Remove active input from a file output node 

    '''

    pass


def parent_set():
    '''Attach selected nodes 

    '''

    pass


def preview_toggle():
    '''Toggle preview display for selected nodes 

    '''

    pass


def properties():
    '''Toggle the properties region visibility 

    '''

    pass


def read_fullsamplelayers():
    '''Read all render layers of current scene, in full sample 

    '''

    pass


def read_renderlayers():
    '''Read all render layers of all used scenes 

    '''

    pass


def render_changed():
    '''Render current scene, when input node’s layer has been changed 

    '''

    pass


def resize():
    '''Resize a node 

    '''

    pass


def select(mouse_x: int = 0, mouse_y: int = 0, extend: bool = False):
    '''Select the node under the cursor 

    :param mouse_x: Mouse X 
    :type mouse_x: int
    :param mouse_y: Mouse Y 
    :type mouse_y: int
    :param extend: Extend 
    :type extend: bool
    '''

    pass


def select_all(action: typing.Union[str, int] = 'TOGGLE'):
    '''(De)select all nodes 

    :param action: Action, Selection action to executeTOGGLE Toggle, Toggle selection for all elements.SELECT Select, Select all elements.DESELECT Deselect, Deselect all elements.INVERT Invert, Invert selection of all elements. 
    :type action: typing.Union[str, int]
    '''

    pass


def select_border(gesture_mode: int = 0,
                  xmin: int = 0,
                  xmax: int = 0,
                  ymin: int = 0,
                  ymax: int = 0,
                  extend: bool = True,
                  tweak: bool = False):
    '''Use box selection to select nodes 

    :param gesture_mode: Gesture Mode 
    :type gesture_mode: int
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    :param tweak: Tweak, Only activate when mouse is not over a node - useful for tweak gesture 
    :type tweak: bool
    '''

    pass


def select_circle(x: int = 0,
                  y: int = 0,
                  radius: int = 1,
                  gesture_mode: int = 0):
    '''Use circle selection to select nodes 

    :param x: X 
    :type x: int
    :param y: Y 
    :type y: int
    :param radius: Radius 
    :type radius: int
    :param gesture_mode: Gesture Mode 
    :type gesture_mode: int
    '''

    pass


def select_grouped(extend: bool = False,
                   type: typing.Union[str, int] = 'TYPE'):
    '''Select nodes with similar properties 

    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def select_lasso(path: typing.List['bpy.types.OperatorMousePath'] = None,
                 deselect: bool = False,
                 extend: bool = True):
    '''Select nodes using lasso selection 

    :param path: Path 
    :type path: typing.List['bpy.types.OperatorMousePath']
    :param deselect: Deselect, Deselect rather than select items 
    :type deselect: bool
    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    '''

    pass


def select_link_viewer(NODE_OT_select=None, NODE_OT_link_viewer=None):
    '''Select node and link it to a viewer node 

    :param NODE_OT_select: Select, Select the node under the cursor 
    :param NODE_OT_link_viewer: Link to Viewer Node, Link to viewer node 
    '''

    pass


def select_linked_from():
    '''Select nodes linked from the selected ones 

    '''

    pass


def select_linked_to():
    '''Select nodes linked to the selected ones 

    '''

    pass


def select_same_type_step(prev: bool = False):
    '''Activate and view same node type, step by step 

    :param prev: Previous 
    :type prev: bool
    '''

    pass


def shader_script_update():
    '''Update shader script node with new sockets and options from the script 

    '''

    pass


def switch_view_update():
    '''Update views of selected node 

    '''

    pass


def toolbar():
    '''Toggles tool shelf display 

    '''

    pass


def translate_attach(TRANSFORM_OT_translate=None,
                     NODE_OT_attach=None,
                     NODE_OT_insert_offset=None):
    '''Move nodes and attach to frame 

    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items 
    :param NODE_OT_attach: Attach Nodes, Attach active node to a frame 
    :param NODE_OT_insert_offset: Insert Offset, Automatically offset nodes on insertion 
    '''

    pass


def translate_attach_remove_on_cancel(TRANSFORM_OT_translate=None,
                                      NODE_OT_attach=None,
                                      NODE_OT_insert_offset=None):
    '''Move nodes and attach to frame 

    :param TRANSFORM_OT_translate: Translate, Translate (move) selected items 
    :param NODE_OT_attach: Attach Nodes, Attach active node to a frame 
    :param NODE_OT_insert_offset: Insert Offset, Automatically offset nodes on insertion 
    '''

    pass


def tree_path_parent():
    '''Go to parent node tree 

    '''

    pass


def tree_socket_add(in_out: typing.Union[str, int] = 'IN'):
    '''Add an input or output socket to the current node tree 

    :param in_out: Socket Type 
    :type in_out: typing.Union[str, int]
    '''

    pass


def tree_socket_move(direction: typing.Union[str, int] = 'UP'):
    '''Move a socket up or down in the current node tree’s sockets stack 

    :param direction: Direction 
    :type direction: typing.Union[str, int]
    '''

    pass


def tree_socket_remove():
    '''Remove an input or output socket to the current node tree 

    '''

    pass


def view_all():
    '''Resize view so you can see all nodes 

    '''

    pass


def view_selected():
    '''Resize view so you can see selected nodes 

    '''

    pass


def viewer_border(gesture_mode: int = 0,
                  xmin: int = 0,
                  xmax: int = 0,
                  ymin: int = 0,
                  ymax: int = 0,
                  extend: bool = True):
    '''Set the boundaries for viewer operations 

    :param gesture_mode: Gesture Mode 
    :type gesture_mode: int
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    :param extend: Extend, Extend selection instead of deselecting everything first 
    :type extend: bool
    '''

    pass



import sys
import typing


def actionzone(modifier: int = 0):
    '''Handle area action zones for mouse actions/gestures 

    :param modifier: Modifier, Modifier state 
    :type modifier: int
    '''

    pass


def animation_cancel(restore_frame: bool = True):
    '''Cancel animation, returning to the original frame 

    :param restore_frame: Restore Frame, Restore the frame when animation was initialized 
    :type restore_frame: bool
    '''

    pass


def animation_play(reverse: bool = False, sync: bool = False):
    '''Play animation 

    :param reverse: Play in Reverse, Animation is played backwards 
    :type reverse: bool
    :param sync: Sync, Drop frames to maintain framerate 
    :type sync: bool
    '''

    pass


def animation_step():
    '''Step through animation by position 

    '''

    pass


def area_dupli():
    '''Duplicate selected area into new window 

    '''

    pass


def area_join(min_x: int = -100,
              min_y: int = -100,
              max_x: int = -100,
              max_y: int = -100):
    '''Join selected areas into new window 

    :param min_x: X 1 
    :type min_x: int
    :param min_y: Y 1 
    :type min_y: int
    :param max_x: X 2 
    :type max_x: int
    :param max_y: Y 2 
    :type max_y: int
    '''

    pass


def area_move(x: int = 0, y: int = 0, delta: int = 0):
    '''Move selected area edges 

    :param x: X 
    :type x: int
    :param y: Y 
    :type y: int
    :param delta: Delta 
    :type delta: int
    '''

    pass


def area_options():
    '''Operations for splitting and merging 

    '''

    pass


def area_split(direction: typing.Union[str, int] = 'HORIZONTAL',
               factor: float = 0.5,
               mouse_x: int = -100,
               mouse_y: int = -100):
    '''Split selected area into new windows 

    :param direction: Direction 
    :type direction: typing.Union[str, int]
    :param factor: Factor 
    :type factor: float
    :param mouse_x: Mouse X 
    :type mouse_x: int
    :param mouse_y: Mouse Y 
    :type mouse_y: int
    '''

    pass


def area_swap():
    '''Swap selected areas screen positions 

    '''

    pass


def back_to_previous():
    '''Revert back to the original screen layout, before fullscreen area overlay 

    '''

    pass


def delete():
    '''Delete active screen 

    '''

    pass


def frame_jump(end: bool = False):
    '''Jump to first/last frame in frame range 

    :param end: Last Frame, Jump to the last frame of the frame range 
    :type end: bool
    '''

    pass


def frame_offset(delta: int = 0):
    '''Move current frame forward/backward by a given number 

    :param delta: Delta 
    :type delta: int
    '''

    pass


def header():
    '''Toggle header display 

    '''

    pass


def header_flip():
    '''Toggle the header over/below the main window area 

    '''

    pass


def header_toggle_menus():
    '''Expand or collapse the header pulldown menus 

    '''

    pass


def header_toolbox():
    '''Display header region toolbox 

    '''

    pass


def keyframe_jump(next: bool = True):
    '''Jump to previous/next keyframe 

    :param next: Next Keyframe 
    :type next: bool
    '''

    pass


def marker_jump(next: bool = True):
    '''Jump to previous/next marker 

    :param next: Next Marker 
    :type next: bool
    '''

    pass


def new():
    '''Add a new screen 

    '''

    pass


def redo_last():
    '''Display menu for last action performed 

    '''

    pass


def region_blend():
    '''Blend in and out overlapping region 

    '''

    pass


def region_flip():
    '''Toggle the region’s alignment (left/right or top/bottom) 

    '''

    pass


def region_quadview():
    '''Split selected area into camera, front, right & top views 

    '''

    pass


def region_scale():
    '''Scale selected area 

    '''

    pass


def repeat_history(index: int = 0):
    '''Display menu for previous actions performed 

    :param index: Index 
    :type index: int
    '''

    pass


def repeat_last():
    '''Repeat last action 

    '''

    pass


def screen_full_area(use_hide_panels: bool = False):
    '''Toggle display selected area as fullscreen/maximized 

    :param use_hide_panels: Hide Panels, Hide all the panels 
    :type use_hide_panels: bool
    '''

    pass


def screen_set(delta: int = 0):
    '''Cycle through available screens 

    :param delta: Delta 
    :type delta: int
    '''

    pass


def screencast(filepath: str = "", full: bool = True):
    '''Capture a video of the active area or whole Blender window 

    :param filepath: filepath 
    :type filepath: str
    :param full: Full Screen, Capture the whole window (otherwise only capture the active area) 
    :type full: bool
    '''

    pass


def screenshot(filepath: str = "",
               check_existing: bool = True,
               filter_blender: bool = False,
               filter_backup: bool = False,
               filter_image: bool = True,
               filter_movie: bool = False,
               filter_python: bool = False,
               filter_font: bool = False,
               filter_sound: bool = False,
               filter_text: bool = False,
               filter_btx: bool = False,
               filter_collada: bool = False,
               filter_alembic: bool = False,
               filter_folder: bool = True,
               filter_blenlib: bool = False,
               filemode: int = 9,
               show_multiview: bool = False,
               use_multiview: bool = False,
               display_type: typing.Union[str, int] = 'DEFAULT',
               sort_method: typing.Union[str, int] = 'FILE_SORT_ALPHA',
               full: bool = True):
    '''Capture a picture of the active area or whole Blender window 

    :param filepath: File Path, Path to file 
    :type filepath: str
    :param check_existing: Check Existing, Check and warn on overwriting existing files 
    :type check_existing: bool
    :param filter_blender: Filter .blend files 
    :type filter_blender: bool
    :param filter_backup: Filter .blend files 
    :type filter_backup: bool
    :param filter_image: Filter image files 
    :type filter_image: bool
    :param filter_movie: Filter movie files 
    :type filter_movie: bool
    :param filter_python: Filter python files 
    :type filter_python: bool
    :param filter_font: Filter font files 
    :type filter_font: bool
    :param filter_sound: Filter sound files 
    :type filter_sound: bool
    :param filter_text: Filter text files 
    :type filter_text: bool
    :param filter_btx: Filter btx files 
    :type filter_btx: bool
    :param filter_collada: Filter COLLADA files 
    :type filter_collada: bool
    :param filter_alembic: Filter Alembic files 
    :type filter_alembic: bool
    :param filter_folder: Filter folders 
    :type filter_folder: bool
    :param filter_blenlib: Filter Blender IDs 
    :type filter_blenlib: bool
    :param filemode: File Browser Mode, The setting for the file browser mode to load a .blend file, a library or a special file 
    :type filemode: int
    :param show_multiview: Enable Multi-View 
    :type show_multiview: bool
    :param use_multiview: Use Multi-View 
    :type use_multiview: bool
    :param display_type: Display TypeDEFAULT Default, Automatically determine display type for files.LIST_SHORT Short List, Display files as short list.LIST_LONG Long List, Display files as a detailed list.THUMBNAIL Thumbnails, Display files as thumbnails. 
    :type display_type: typing.Union[str, int]
    :param sort_method: File sorting modeFILE_SORT_ALPHA Sort alphabetically, Sort the file list alphabetically.FILE_SORT_EXTENSION Sort by extension, Sort the file list by extension/type.FILE_SORT_TIME Sort by time, Sort files by modification time.FILE_SORT_SIZE Sort by size, Sort files by size. 
    :type sort_method: typing.Union[str, int]
    :param full: Full Screen, Capture the whole window (otherwise only capture the active area) 
    :type full: bool
    '''

    pass


def space_context_cycle(direction: typing.Union[str, int] = 'NEXT'):
    '''Cycle through the editor context by activating the next/previous one 

    :param direction: Direction, Direction to cycle through 
    :type direction: typing.Union[str, int]
    '''

    pass


def spacedata_cleanup():
    '''Remove unused settings for invisible editors 

    '''

    pass


def userpref_show():
    '''Show user preferences 

    '''

    pass



import sys
import typing


def action_set(action: typing.Union[str, int] = ''):
    '''Change the active action used 

    :param action: Action 
    :type action: typing.Union[str, int]
    '''

    pass


def animdata_operation(type: typing.Union[str, int] = 'CLEAR_ANIMDATA'):
    '''Undocumented 

    :param type: Animation OperationCLEAR_ANIMDATA Clear Animation Data, Remove this animation data container.SET_ACT Set Action.CLEAR_ACT Unlink Action.REFRESH_DRIVERS Refresh Drivers.CLEAR_DRIVERS Clear Drivers. 
    :type type: typing.Union[str, int]
    '''

    pass


def constraint_operation(type: typing.Union[str, int] = 'ENABLE'):
    '''Undocumented 

    :param type: Constraint Operation 
    :type type: typing.Union[str, int]
    '''

    pass


def data_operation(type: typing.Union[str, int] = 'SELECT'):
    '''Undocumented 

    :param type: Data Operation 
    :type type: typing.Union[str, int]
    '''

    pass


def drivers_add_selected():
    '''Add drivers to selected items 

    '''

    pass


def drivers_delete_selected():
    '''Delete drivers assigned to selected items 

    '''

    pass


def expanded_toggle():
    '''Expand/Collapse all items 

    '''

    pass


def group_link(object: str = "Object"):
    '''Link Object to Group in Outliner 

    :param object: Object, Target Object 
    :type object: str
    '''

    pass


def group_operation(type: typing.Union[str, int] = 'UNLINK'):
    '''Undocumented 

    :param type: Group OperationUNLINK Unlink Group.LOCAL Make Local Group.LINK Link Group Objects to Scene.DELETE Delete Group.REMAP Remap Users, Make all users of selected data-blocks to use instead current (clicked) one.INSTANCE Instance Groups in Scene.TOGVIS Toggle Visible Group.TOGSEL Toggle Selectable.TOGREN Toggle Renderable.RENAME Rename. 
    :type type: typing.Union[str, int]
    '''

    pass


def id_delete():
    '''Delete the ID under cursor 

    '''

    pass


def id_operation(type: typing.Union[str, int] = 'UNLINK'):
    '''Undocumented 

    :param type: ID data OperationUNLINK Unlink.LOCAL Make Local.SINGLE Make Single User.DELETE Delete, WARNING: no undo.REMAP Remap Users, Make all users of selected data-blocks to use instead current (clicked) one.ADD_FAKE Add Fake User, Ensure data-block gets saved even if it isn’t in use (e.g. for motion and material libraries).CLEAR_FAKE Clear Fake User.RENAME Rename.SELECT_LINKED Select Linked. 
    :type type: typing.Union[str, int]
    '''

    pass


def id_remap(id_type: typing.Union[str, int] = 'OBJECT',
             old_id: typing.Union[str, int] = '',
             new_id: typing.Union[str, int] = ''):
    '''Undocumented 

    :param id_type: ID Type 
    :type id_type: typing.Union[str, int]
    :param old_id: Old ID, Old ID to replace 
    :type old_id: typing.Union[str, int]
    :param new_id: New ID, New ID to remap all selected IDs’ users to 
    :type new_id: typing.Union[str, int]
    '''

    pass


def item_activate(extend: bool = True, recursive: bool = False):
    '''Handle mouse clicks to activate/select items 

    :param extend: Extend, Extend selection for activation 
    :type extend: bool
    :param recursive: Recursive, Select Objects and their children 
    :type recursive: bool
    '''

    pass


def item_openclose(all: bool = True):
    '''Toggle whether item under cursor is enabled or closed 

    :param all: All, Close or open all items 
    :type all: bool
    '''

    pass


def item_rename():
    '''Rename item under cursor 

    '''

    pass


def keyingset_add_selected():
    '''Add selected items (blue-gray rows) to active Keying Set 

    '''

    pass


def keyingset_remove_selected():
    '''Remove selected items (blue-gray rows) from active Keying Set 

    '''

    pass


def lib_operation(type: typing.Union[str, int] = 'RENAME'):
    '''Undocumented 

    :param type: Library OperationRENAME Rename.DELETE Delete, Delete this library and all its item from Blender - WARNING: no undo.RELOCATE Relocate, Select a new path for this library, and reload all its data.RELOAD Reload, Reload all data from this library. 
    :type type: typing.Union[str, int]
    '''

    pass


def lib_relocate():
    '''Relocate the library under cursor 

    '''

    pass


def material_drop(object: str = "Object", material: str = "Material"):
    '''Drag material to object in Outliner 

    :param object: Object, Target Object 
    :type object: str
    :param material: Material, Target Material 
    :type material: str
    '''

    pass


def modifier_operation(type: typing.Union[str, int] = 'TOGVIS'):
    '''Undocumented 

    :param type: Modifier Operation 
    :type type: typing.Union[str, int]
    '''

    pass


def object_operation(type: typing.Union[str, int] = 'SELECT'):
    '''Undocumented 

    :param type: Object OperationSELECT Select.DESELECT Deselect.SELECT_HIERARCHY Select Hierarchy.DELETE Delete.DELETE_HIERARCHY Delete Hierarchy.REMAP Remap Users, Make all users of selected data-blocks to use instead a new chosen one.TOGVIS Toggle Visible.TOGSEL Toggle Selectable.TOGREN Toggle Renderable.RENAME Rename. 
    :type type: typing.Union[str, int]
    '''

    pass


def operation():
    '''Context menu for item operations 

    '''

    pass


def orphans_purge():
    '''Clear all orphaned data-blocks without any users from the file (cannot be undone, saves to current .blend file) 

    '''

    pass


def parent_clear(dragged_obj: str = "Object",
                 type: typing.Union[str, int] = 'CLEAR'):
    '''Drag to clear parent in Outliner 

    :param dragged_obj: Child, Child Object 
    :type dragged_obj: str
    :param type: TypeCLEAR Clear Parent, Completely clear the parenting relationship, including involved modifiers if any.CLEAR_KEEP_TRANSFORM Clear and Keep Transformation, As ‘Clear Parent’, but keep the current visual transformations of the object.CLEAR_INVERSE Clear Parent Inverse, Reset the transform corrections applied to the parenting relationship, does not remove parenting itself. 
    :type type: typing.Union[str, int]
    '''

    pass


def parent_drop(child: str = "Object",
                parent: str = "Object",
                type: typing.Union[str, int] = 'OBJECT'):
    '''Drag to parent in Outliner 

    :param child: Child, Child Object 
    :type child: str
    :param parent: Parent, Parent Object 
    :type parent: str
    :param type: Type 
    :type type: typing.Union[str, int]
    '''

    pass


def renderability_toggle():
    '''Toggle the renderability of selected items 

    '''

    pass


def scene_drop(object: str = "Object", scene: str = "Scene"):
    '''Drag object to scene in Outliner 

    :param object: Object, Target Object 
    :type object: str
    :param scene: Scene, Target Scene 
    :type scene: str
    '''

    pass


def scene_operation(type: typing.Union[str, int] = 'DELETE'):
    '''Context menu for scene operations 

    :param type: Scene Operation 
    :type type: typing.Union[str, int]
    '''

    pass


def scroll_page(up: bool = False):
    '''Scroll page up or down 

    :param up: Up, Scroll up one page 
    :type up: bool
    '''

    pass


def select_border(gesture_mode: int = 0,
                  xmin: int = 0,
                  xmax: int = 0,
                  ymin: int = 0,
                  ymax: int = 0):
    '''Use box selection to select tree elements 

    :param gesture_mode: Gesture Mode 
    :type gesture_mode: int
    :param xmin: X Min 
    :type xmin: int
    :param xmax: X Max 
    :type xmax: int
    :param ymin: Y Min 
    :type ymin: int
    :param ymax: Y Max 
    :type ymax: int
    '''

    pass


def selectability_toggle():
    '''Toggle the selectability 

    '''

    pass


def selected_toggle():
    '''Toggle the Outliner selection of items 

    '''

    pass


def show_active():
    '''Open up the tree and adjust the view so that the active Object is shown centered 

    '''

    pass


def show_hierarchy():
    '''Open all object entries and close all others 

    '''

    pass


def show_one_level(open: bool = True):
    '''Expand/collapse all entries by one level 

    :param open: Open, Expand all entries one level deep 
    :type open: bool
    '''

    pass


def visibility_toggle():
    '''Toggle the visibility of selected items 

    '''

    pass



import sys
import typing


class NodeCategory:
    def poll(self, context):
        '''

        '''
        pass


class NodeItem:
    label = None
    ''''''

    translation_context = None
    ''''''

    def draw(self, layout, context):
        '''

        '''
        pass


class NodeItemCustom:
    pass


def draw_node_categories_menu(context):
    '''

    '''

    pass


def node_categories_iter(context):
    '''

    '''

    pass


def node_items_iter(context):
    '''

    '''

    pass


def register_node_categories(identifier, cat_list):
    '''

    '''

    pass


def unregister_node_cat_types(cats):
    '''

    '''

    pass


def unregister_node_categories(identifier):
    '''

    '''

    pass



import sys
import typing


def cycles_integrator_preset_add(name: str = "", remove_active: bool = False):
    '''Add an Integrator Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass


def cycles_sampling_preset_add(name: str = "", remove_active: bool = False):
    '''Add a Sampling Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass


def opengl(animation: bool = False,
           sequencer: bool = False,
           write_still: bool = False,
           view_context: bool = True):
    '''OpenGL render active viewport 

    :param animation: Animation, Render files from the animation range of this scene 
    :type animation: bool
    :param sequencer: Sequencer, Render using the sequencer’s OpenGL display 
    :type sequencer: bool
    :param write_still: Write Image, Save rendered the image to the output path (used only when animation is disabled) 
    :type write_still: bool
    :param view_context: View Context, Use the current 3D view for rendering, else use scene settings 
    :type view_context: bool
    '''

    pass


def play_rendered_anim():
    '''Play back rendered frames/movies using an external player 

    '''

    pass


def preset_add(name: str = "", remove_active: bool = False):
    '''Add or remove a Render Preset 

    :param name: Name, Name of the preset, used to make the path name 
    :type name: str
    :param remove_active: remove_active 
    :type remove_active: bool
    '''

    pass


def render(animation: bool = False,
           write_still: bool = False,
           use_viewport: bool = False,
           layer: str = "",
           scene: str = ""):
    '''Render active scene 

    :param animation: Animation, Render files from the animation range of this scene 
    :type animation: bool
    :param write_still: Write Image, Save rendered the image to the output path (used only when animation is disabled) 
    :type write_still: bool
    :param use_viewport: Use 3D Viewport, When inside a 3D viewport, use layers and camera of the viewport 
    :type use_viewport: bool
    :param layer: Render Layer, Single render layer to re-render (used only when animation is disabled) 
    :type layer: str
    :param scene: Scene, Scene to render, current scene if not specified 
    :type scene: str
    '''

    pass


def shutter_curve_preset(shape: typing.Union[str, int] = 'SMOOTH'):
    '''Set shutter curve 

    :param shape: Mode 
    :type shape: typing.Union[str, int]
    '''

    pass


def view_cancel():
    '''Cancel show render view 

    '''

    pass


def view_show():
    '''Toggle show render view 

    '''

    pass



import sys
import typing
import mathutils

from . import types


def cell(position: 'mathutils.Vector') -> float:
    '''Returns cell noise value at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :return:  The cell noise value. 
    '''

    pass


def cell_vector(position: 'mathutils.Vector') -> 'mathutils.Vector':
    '''Returns cell noise vector at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :return:  The cell noise vector. 
    '''

    pass


def fractal(position: 'mathutils.Vector',
            H: float,
            lacunarity: float,
            octaves: int,
            noise_basis: int = types.STDPERLIN) -> float:
    '''Returns the fractal Brownian motion (fBm) noise value from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param H: The fractal increment factor. 
    :type H: float
    :param lacunarity: The gap between successive frequencies. 
    :type lacunarity: float
    :param octaves: The number of different noise frequencies used. 
    :type octaves: int
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :return:  The fractal Brownian motion noise value. 
    '''

    pass


def hetero_terrain(position: 'mathutils.Vector',
                   H: float,
                   lacunarity: float,
                   octaves: int,
                   offset: float,
                   noise_basis: int = types.STDPERLIN) -> float:
    '''Returns the heterogeneous terrain value from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param H: The fractal dimension of the roughest areas. 
    :type H: float
    :param lacunarity: The gap between successive frequencies. 
    :type lacunarity: float
    :param octaves: The number of different noise frequencies used. 
    :type octaves: int
    :param offset: The height of the terrain above ‘sea level’. 
    :type offset: float
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :return:  The heterogeneous terrain value. 
    '''

    pass


def hybrid_multi_fractal(position: 'mathutils.Vector',
                         H: float,
                         lacunarity: float,
                         octaves: int,
                         offset: float,
                         gain: float,
                         noise_basis: int = types.STDPERLIN) -> float:
    '''Returns hybrid multifractal value from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param H: The fractal dimension of the roughest areas. 
    :type H: float
    :param lacunarity: The gap between successive frequencies. 
    :type lacunarity: float
    :param octaves: The number of different noise frequencies used. 
    :type octaves: int
    :param offset: The height of the terrain above ‘sea level’. 
    :type offset: float
    :param gain: Scaling applied to the values. 
    :type gain: float
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :return:  The hybrid multifractal value. 
    '''

    pass


def multi_fractal(position: 'mathutils.Vector',
                  H: float,
                  lacunarity: float,
                  octaves: int,
                  noise_basis: int = types.STDPERLIN) -> float:
    '''Returns multifractal noise value from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param H: The fractal increment factor. 
    :type H: float
    :param lacunarity: The gap between successive frequencies. 
    :type lacunarity: float
    :param octaves: The number of different noise frequencies used. 
    :type octaves: int
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :return:  The multifractal noise value. 
    '''

    pass


def noise(position: 'mathutils.Vector',
          noise_basis: int = types.STDPERLIN) -> float:
    '''Returns noise value from the noise basis at the position specified. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :return:  The noise value. 
    '''

    pass


def noise_vector(position: 'mathutils.Vector',
                 noise_basis: int = types.STDPERLIN) -> 'mathutils.Vector':
    '''Returns the noise vector from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :return:  The noise vector. 
    '''

    pass


def random() -> float:
    '''Returns a random number in the range [0, 1]. 

    :return:  The random number. 
    '''

    pass


def random_unit_vector(size=3) -> 'mathutils.Vector':
    '''Returns a unit vector with random entries. 

    :param size: The size of the vector to be produced. 
    :return:  The random unit vector. 
    '''

    pass


def ridged_multi_fractal(position: 'mathutils.Vector',
                         H: float,
                         lacunarity: float,
                         octaves: int,
                         offset: float,
                         gain: float,
                         noise_basis: int = types.STDPERLIN) -> float:
    '''Returns ridged multifractal value from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param H: The fractal dimension of the roughest areas. 
    :type H: float
    :param lacunarity: The gap between successive frequencies. 
    :type lacunarity: float
    :param octaves: The number of different noise frequencies used. 
    :type octaves: int
    :param offset: The height of the terrain above ‘sea level’. 
    :type offset: float
    :param gain: Scaling applied to the values. 
    :type gain: float
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :return:  The ridged multifractal value. 
    '''

    pass


def seed_set(seed):
    '''Sets the random seed used for random_unit_vector, random_vector and random. 

    :param seed: Seed used for the random generator. When seed is zero, the current time will be used instead. 
    '''

    pass


def turbulence(position: 'mathutils.Vector',
               octaves: int,
               hard,
               noise_basis: int = types.STDPERLIN,
               amplitude_scale: float = 0.5,
               frequency_scale: int = 2.0) -> float:
    '''Returns the turbulence value from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param octaves: The number of different noise frequencies used. 
    :type octaves: int
    :param hard: Specifies whether returned turbulence is hard (sharp transitions) or soft (smooth transitions). 
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :param amplitude_scale: The amplitude scaling factor. 
    :type amplitude_scale: float
    :param frequency_scale: The frequency scaling factor 
    :type frequency_scale: int
    :return:  The turbulence value. 
    '''

    pass


def turbulence_vector(position: 'mathutils.Vector',
                      octaves: int,
                      hard,
                      noise_basis: int = types.STDPERLIN,
                      amplitude_scale: float = 0.5,
                      frequency_scale: int = 2.0) -> 'mathutils.Vector':
    '''Returns the turbulence vector from the noise basis at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param octaves: The number of different noise frequencies used. 
    :type octaves: int
    :param hard: Specifies whether returned turbulence is hard (sharp transitions) or soft (smooth transitions). 
    :param noise_basis: The type of noise to be evaluated. 
    :type noise_basis: int
    :param amplitude_scale: The amplitude scaling factor. 
    :type amplitude_scale: float
    :param frequency_scale: The frequency scaling factor 
    :type frequency_scale: int
    :return:  The turbulence vector. 
    '''

    pass


def variable_lacunarity(position: 'mathutils.Vector',
                        distortion: float,
                        noise_type1: int = types.STDPERLIN,
                        noise_type2: int = types.STDPERLIN) -> float:
    '''Returns variable lacunarity noise value, a distorted variety of noise, from noise type 1 distorted by noise type 2 at the specified position. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param distortion: The amount of distortion. 
    :type distortion: float
    :param noise_type1: The type of noise to be distorted. 
    :type noise_type1: int
    :param noise_type2: The type of noise used to distort noise_type1. 
    :type noise_type2: int
    :return:  The variable lacunarity noise value. 
    '''

    pass


def voronoi(position: 'mathutils.Vector',
            distance_metric: int = None,
            exponent: float = 2.5) -> typing.List['mathutils.Vector']:
    '''Returns a list of distances to the four closest features and their locations. 

    :param position: The position to evaluate the selected noise function at. 
    :type position: 'mathutils.Vector'
    :param distance_metric: Method of measuring distance. 
    :type distance_metric: int
    :param exponent: The exponent for Minkowski distance metric. 
    :type exponent: float
    :return:  A list of distances to the four closest features and their locations. 
    '''

    pass



import sys
import typing


def cancel_stroke():
    '''Cancel the current sketch stroke 

    '''

    pass


def convert():
    '''Convert the selected sketch strokes to bone chains 

    '''

    pass


def delete():
    '''Delete a sketch stroke 

    '''

    pass


def draw_preview(snap: bool = False):
    '''Draw preview of current sketch stroke (internal use) 

    :param snap: Snap 
    :type snap: bool
    '''

    pass


def draw_stroke(snap: bool = False):
    '''Start to draw a sketch stroke 

    :param snap: Snap 
    :type snap: bool
    '''

    pass


def finish_stroke():
    '''End and keep the current sketch stroke 

    '''

    pass


def gesture(snap: bool = False):
    '''Start to draw a gesture stroke 

    :param snap: Snap 
    :type snap: bool
    '''

    pass


def select():
    '''Select a sketch stroke 

    '''

    pass



import sys
import typing


class ProgressReport:
    curr_step = None
    ''''''

    running = None
    ''''''

    start_time = None
    ''''''

    steps = None
    ''''''

    wm = None
    ''''''

    def enter_substeps(self, nbr, msg):
        '''

        '''
        pass

    def finalize(self):
        '''

        '''
        pass

    def initialize(self, wm):
        '''

        '''
        pass

    def leave_substeps(self, msg):
        '''

        '''
        pass

    def start(self):
        '''

        '''
        pass

    def step(self, msg, nbr):
        '''

        '''
        pass

    def update(self, msg):
        '''

        '''
        pass


class ProgressReportSubstep:
    final_msg = None
    ''''''

    level = None
    ''''''

    msg = None
    ''''''

    nbr = None
    ''''''

    progress = None
    ''''''

    def enter_substeps(self, nbr, msg):
        '''

        '''
        pass

    def leave_substeps(self, msg):
        '''

        '''
        pass

    def step(self, msg, nbr):
        '''

        '''
        pass



import sys
import typing


def create(name: str = "Group"):
    '''Create an object group from selected objects 

    :param name: Name, Name of the new group 
    :type name: str
    '''

    pass


def objects_add_active(group: typing.Union[str, int] = ''):
    '''Add the object to an object group that contains the active object 

    :param group: Group, The group to add other selected objects to 
    :type group: typing.Union[str, int]
    '''

    pass


def objects_remove(group: typing.Union[str, int] = ''):
    '''Remove selected objects from a group 

    :param group: Group, The group to remove this object from 
    :type group: typing.Union[str, int]
    '''

    pass


def objects_remove_active(group: typing.Union[str, int] = ''):
    '''Remove the object from an object group that contains the active object 

    :param group: Group, The group to remove other selected objects from 
    :type group: typing.Union[str, int]
    '''

    pass


def objects_remove_all():
    '''Remove selected objects from all groups 

    '''

    pass
